import { RsbuildPlugin } from '@rsbuild/core';
import { ChainedConfigWithUtils, NormalizedConfig } from '@rsbuild/shared';
import { PluginItem, TransformOptions } from '@babel/core';
export { TransformOptions as BabelTransformOptions } from '@babel/core';

type PresetEnvTargets = string | string[] | Record<string, string>;
type PresetEnvBuiltIns = 'usage' | 'entry' | false;
type PresetEnvOptions = {
    targets?: PresetEnvTargets;
    bugfixes?: boolean;
    spec?: boolean;
    loose?: boolean;
    modules?: 'amd' | 'umd' | 'systemjs' | 'commonjs' | 'cjs' | 'auto' | false;
    debug?: boolean;
    include?: string[];
    exclude?: string[];
    useBuiltIns?: PresetEnvBuiltIns;
    corejs?: string | {
        version: string;
        proposals: boolean;
    };
    forceAllTransforms?: boolean;
    configPath?: string;
    ignoreBrowserslistConfig?: boolean;
    browserslistEnv?: string;
    shippedProposals?: boolean;
};
interface SharedBabelPresetReactOptions {
    development?: boolean;
    throwIfNamespace?: boolean;
}
interface AutomaticRuntimePresetReactOptions extends SharedBabelPresetReactOptions {
    runtime?: 'automatic';
    importSource?: string;
}
interface ClassicRuntimePresetReactOptions extends SharedBabelPresetReactOptions {
    runtime?: 'classic';
    pragma?: string;
    pragmaFrag?: string;
    useBuiltIns?: boolean;
    useSpread?: boolean;
}
type PresetReactOptions = AutomaticRuntimePresetReactOptions | ClassicRuntimePresetReactOptions;
type BabelConfigUtils = {
    addPlugins: (plugins: PluginItem[]) => void;
    addPresets: (presets: PluginItem[]) => void;
    removePlugins: (plugins: string | string[]) => void;
    removePresets: (presets: string | string[]) => void;
    modifyPresetEnvOptions: (options: PresetEnvOptions) => void;
    modifyPresetReactOptions: (options: PresetReactOptions) => void;
    /**
     * use `source.include` instead
     * @deprecated
     */
    addIncludes: (includes: string | RegExp | (string | RegExp)[]) => void;
    /**
     * use `source.exclude` instead
     * @deprecated
     */
    addExcludes: (excludes: string | RegExp | (string | RegExp)[]) => void;
};
type PluginBabelOptions = {
    babelLoaderOptions?: ChainedConfigWithUtils<TransformOptions, BabelConfigUtils>;
};

declare const pluginBabel: (options?: PluginBabelOptions) => RsbuildPlugin;

declare const getBabelUtils: (config: TransformOptions) => BabelConfigUtils;
declare const getUseBuiltIns: (config: NormalizedConfig) => false | "usage" | "entry";

export { BabelConfigUtils, PluginBabelOptions, PresetEnvBuiltIns, PresetEnvOptions, PresetEnvTargets, getBabelUtils, getUseBuiltIns, pluginBabel };
